@@ -8,7 +8,7 @@ package XS::Parse::Sublike;
 use strict;
 use warnings;
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 require XSLoader;
 XSLoader::load( __PACKAGE__, $VERSION );
@@ -114,6 +114,17 @@ various fields of the C<XSParseSublikeContext> structure.
 The C<XSParseSublikeHooks> structure provides the following hook stages, which
 are invoked in the given order.
 
+The structure has a I<flags> field, which controls various optional parts of
+operation. The following flags are defined.
+
+=over 4
+
+=item XS_PARSE_SUBLIKE_FLAG_FILTERATTRS
+
+If set, the optional C<filter_attr> stage will be invoked.
+
+=back
+
 In addition there are two C<U8> fields named I<require_parts> and
 I<skip_parts> which control the behaviour of various parts of the syntax which
 are usually optional. Any parts with bits set in I<require_parts> become
@@ -184,6 +195,22 @@ Invoked just before C<start_subparse()> is called.
 At this point the optional sub attributes are parsed and filled into the
 C<attrs> field of the context, then C<block_start()> is called.
 
+=head2 The optional C<filter_attr> Stage
+
+   bool (*filter_attr)(pTHX_ struct XSParseSublikeContext *ctx,
+      SV *attr, SV *val);
+
+If the I<flags> field includes C<XS_PARSE_SUBLIKE_FLAG_FILTERATTRS> then each
+individual attribute is passed through this optional filter function
+immediately as each is parsed. I<attr> will be a string SV containing the name
+of the attribute, and I<val> will either be C<NULL>, or a string SV containing
+the contents of the parens after its name (without the parens themselves).
+
+If the filter returns C<true>, it indicates that it has in some way handled
+the attribute and it should not be added to the list given to C<newATTRSUB()>.
+If the filter returns C<false> it will be handled in the usual way; equivalent
+to the case where the filter function did not exist.
+
 =head2 The C<post_blockstart> Stage
 
    void (*post_blockstart)(pTHX_ struct XSParseSublikeContext *ctx)
